DEFAULT_SET_AGGREGATIONS = {
	"a_": ["tot",],
	"a": [10, 20, 30, 40, 50, 60, 70, 80, 90, 100],

	"c_": ['cTot',],
	"c" : ['cBil', 'cEne', 'cVar', 'cBol', 'cTje', 'cTur'],

	"x_": ['xTot',],
	"x" : ['xEne', 'xVar', 'xSoe', 'xTje', 'xTur'],

	"g_": ['gTot',],
	"g" : ['g',],

	"s_": ['tot',],
	"sp": ['tje', 'fre', 'byg', 'soe', 'bol', 'lan', 'ene', 'udv'],
	"s" : ['tje', 'fre', 'byg', 'soe', 'bol', 'lan', 'ene', 'udv', 'off'],
	"r_": ['rTot',],
	"r" : ['tje', 'fre', 'byg', 'soe', 'bol', 'lan', 'ene', 'udv', 'off'],

	"i_": ['iTot',],
	"i" : ['iM', 'iB', 'iL'],

	"k_": ['iM', 'iB'],
	"k" : ['iM', 'iB'],

  "portf": ['Net',],
  "portf_": ['Net',],

  "scen_": ['GovSpending', 'IntRate', 'ForeignDemand'],
}

AGE_AXIS_TITLE = "Alder"
TIME_AXIS_TITLE = "År"

YAXIS_TITLE_FROM_OPERATOR = {
	"pq": "Pct.-ændringer relativt til grundforløb",
	"q": "Ændring relativt til grundforløb",
	"m": "Forskel fra grundfoløb",
}
